@@ -48,7 +48,8 @@
 #include "httpserver.h"
 #include "bandwidthscheduler.h"
 #include <libtorrent/extensions/ut_metadata.hpp>
-#ifdef LIBTORRENT_0_15
+#include <libtorrent/version.hpp>
+#if LIBTORRENT_VERSION_MINOR > 14
 #include <libtorrent/extensions/lt_trackers.hpp>
 #endif
 #include <libtorrent/extensions/ut_pex.hpp>
@@ -112,13 +113,13 @@ Bittorrent::Bittorrent()
   addConsoleMessage("Peer ID: "+misc::toQString(fingerprint(peer_id.toLocal8Bit().constData(), version.at(0), version.at(1), version.at(2), version.at(3)).to_string()));
 
   // Set severity level of libtorrent session
-  s->set_alert_mask(alert::error_notification | alert::peer_notification | alert::port_mapping_notification | alert::storage_notification | alert::tracker_notification | alert::status_notification | alert::ip_block_notification);
+  s->set_alert_mask(alert::error_notification | alert::peer_notification | alert::port_mapping_notification | alert::storage_notification | alert::tracker_notification | alert::status_notification | alert::ip_block_notification | alert::progress_notification);
   // Load previous state
   loadSessionState();
   // Enabling plugins
   //s->add_extension(&create_metadata_plugin);
   s->add_extension(&create_ut_metadata_plugin);
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
   s->add_extension(create_lt_trackers_plugin);
 #endif
   if(Preferences::isPeXEnabled()) {
@@ -138,7 +139,7 @@ Bittorrent::Bittorrent()
   connect(downloader, SIGNAL(downloadFinished(QString, QString)), this, SLOT(processDownloadedFile(QString, QString)));
   connect(downloader, SIGNAL(downloadFailure(QString, QString)), this, SLOT(handleDownloadFailure(QString, QString)));
   appendLabelToSavePath = Preferences::appendTorrentLabel();
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
   appendqBExtension = Preferences::useIncompleteFilesExtension();
 #endif
   connect(m_scanFolders, SIGNAL(torrentsAdded(QStringList&)), this, SLOT(addTorrentsFromScanFolder(QStringList&)));
@@ -151,7 +152,7 @@ session_proxy Bittorrent::asyncDeletion() {
   qDebug("Bittorrent session async deletion IN");
   exiting = true;
   // Do some BT related saving
-#ifndef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR < 15
   saveDHTEntry();
 #endif
   saveSessionState();
@@ -168,7 +169,7 @@ Bittorrent::~Bittorrent() {
   qDebug("BTSession destructor IN");
   if(!exiting) {
     // Do some BT related saving
- #ifndef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR < 15
     saveDHTEntry();
 #endif
     saveSessionState();
@@ -216,7 +217,7 @@ void Bittorrent::deleteBigRatios() {
     if(h.is_seed()) {
       const QString hash = h.hash();
       const float ratio = getRealRatio(hash);
-      if(ratio <= MAX_RATIO && ratio > ratio_limit) {
+      if(ratio <= MAX_RATIO && ratio >= ratio_limit) {
         addConsoleMessage(tr("%1 reached the maximum ratio you set.").arg(h.name()));
         deleteTorrent(hash);
         //emit torrent_ratio_deleted(fileName);
@@ -278,20 +279,20 @@ void Bittorrent::configureSession() {
     setDefaultTempPath(QString::null);
   }
   setAppendLabelToSavePath(Preferences::appendTorrentLabel());
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
   setAppendqBExtension(Preferences::useIncompleteFilesExtension());
 #endif
   preAllocateAllFiles(Preferences::preAllocateAllFiles());
   startTorrentsInPause(Preferences::addTorrentsInPause());
   // * Scan dirs
   const QStringList &scan_dirs = Preferences::getScanDirs();
-  QVariantList downloadInDirList = Preferences::getDownloadInScanDirs();
+  QList<bool> downloadInDirList = Preferences::getDownloadInScanDirs();
   while(scan_dirs.size() > downloadInDirList.size()) {
-    downloadInDirList << QVariant(false);
+    downloadInDirList << false;
   }
   int i = 0;
   foreach (const QString &dir, scan_dirs) {
-    m_scanFolders->addPath(dir, downloadInDirList.at(i).toBool());
+    m_scanFolders->addPath(dir, downloadInDirList.at(i));
     ++i;
   }
   // * Export Dir
@@ -420,7 +421,8 @@ void Bittorrent::configureSession() {
   sessionSettings.stop_tracker_timeout = 1;
   //sessionSettings.announce_to_all_trackers = true;
   sessionSettings.auto_scrape_interval = 1200; // 20 minutes
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
+  sessionSettings.announce_to_all_trackers = true;
   sessionSettings.announce_to_all_tiers = true; //uTorrent behavior
   sessionSettings.auto_scrape_min_interval = 900; // 15 minutes
 #endif
@@ -624,7 +626,7 @@ bool Bittorrent::initWebUi(QString username, QString password, int port) {
     else
       addConsoleMessage(tr("Web User Interface Error - Unable to bind Web UI to port %1").arg(port), "red");
   }
-  return success; 
+  return success;
 }
 
 void Bittorrent::useAlternativeSpeedsLimit(bool alternative) {
@@ -635,8 +637,20 @@ void Bittorrent::useAlternativeSpeedsLimit(bool alternative) {
     s->set_download_rate_limit(Preferences::getAltGlobalDownloadLimit()*1024);
     s->set_upload_rate_limit(Preferences::getAltGlobalUploadLimit()*1024);
   } else {
-    s->set_download_rate_limit(Preferences::getGlobalDownloadLimit()*1024);
-    s->set_upload_rate_limit(Preferences::getGlobalUploadLimit()*1024);
+    int down_limit = Preferences::getGlobalDownloadLimit();
+    if(down_limit <= 0) {
+      down_limit = -1;
+    } else {
+      down_limit *= 1024;
+    }
+    s->set_download_rate_limit(down_limit);
+    int up_limit = Preferences::getGlobalUploadLimit();
+    if(up_limit <= 0) {
+      up_limit = -1;
+    } else {
+      up_limit *= 1024;
+    }
+    s->set_upload_rate_limit(up_limit);
   }
   emit alternativeSpeedsModeChanged(alternative);
 }
@@ -851,7 +865,7 @@ QTorrentHandle Bittorrent::addMagnetUri(QString magnet_uri, bool resumed) {
     qDebug("addMagnetURI: using save_path: %s", qPrintable(savePath));
   }
 
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
   // Skip checking and directly start seeding (new in libtorrent v0.15)
   if(TorrentTempData::isSeedingMode(hash)){
     p.seed_mode=true;
@@ -937,6 +951,15 @@ QTorrentHandle Bittorrent::addTorrent(QString path, bool fromScanDir, QString fr
   QString hash;
   boost::intrusive_ptr<torrent_info> t;
 
+#ifdef Q_WS_WIN
+  // Windows hack
+  if(!path.endsWith(".torrent")) {
+    if(QFile::rename(path, path+".torrent"))
+      path += ".torrent";
+  }
+  qDebug("Downloading torrent at path: %s", qPrintable(path));
+#endif
+
   // Checking if BT_backup Dir exists
   // create it if it is not
   if(! torrentBackup.exists()) {
@@ -955,7 +978,7 @@ QTorrentHandle Bittorrent::addTorrent(QString path, bool fromScanDir, QString fr
   qDebug("Adding %s to download list", qPrintable(file));
   try {
     // Getting torrent file informations
-    t = new torrent_info(file.toLocal8Bit().constData());
+    t = new torrent_info(file.toUtf8().constData());
     if(!t->is_valid())
       throw std::exception();
   } catch(std::exception&) {
@@ -1041,7 +1064,7 @@ QTorrentHandle Bittorrent::addTorrent(QString path, bool fromScanDir, QString fr
   //Getting fast resume data if existing
   std::vector<char> buf;
   if(resumed) {
-    const QString fastresume_path = torrentBackup.path()+QDir::separator()+hash+QString(".fastresume");
+    const QString fastresume_path = torrentBackup.absoluteFilePath(hash+QString(".fastresume"));
     qDebug("Trying to load fastresume data: %s", qPrintable(fastresume_path));
     if (load_file(fastresume_path.toLocal8Bit().constData(), buf) == 0) {
       fastResume = true;
@@ -1065,7 +1088,7 @@ QTorrentHandle Bittorrent::addTorrent(QString path, bool fromScanDir, QString fr
     qDebug("addTorrent: using save_path: %s", qPrintable(savePath));
   }
 
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
   // Skip checking and directly start seeding (new in libtorrent v0.15)
   if(TorrentTempData::isSeedingMode(hash)){
     p.seed_mode=true;
@@ -1124,9 +1147,20 @@ QTorrentHandle Bittorrent::addTorrent(QString path, bool fromScanDir, QString fr
       bool force_recheck = false;
       if(files_path.size() == h.num_files()) {
         for(int i=0; i<h.num_files(); ++i) {
+          QString old_path = h.files_path().at(i);
+          old_path = old_path.replace("\\", "/");
+          if(!QFile::exists(old_path)) {
+            // Remove old parent folder manually since we will
+            // not get a file_renamed alert
+            QStringList parts = old_path.split("/", QString::SkipEmptyParts);
+            parts.removeLast();
+            if(!parts.empty())
+              QDir().rmpath(parts.join("/"));
+          }
           const QString &path = files_path.at(i);
-          if(!force_recheck && QFile::exists(h.save_path()+QDir::separator()+path))
+          if(!force_recheck && QDir(h.save_path()).exists(path))
             force_recheck = true;
+          qDebug("Renaming file to %s", qPrintable(path));
           h.rename_file(i, path);
         }
         // Force recheck
@@ -1145,7 +1179,7 @@ QTorrentHandle Bittorrent::addTorrent(QString path, bool fromScanDir, QString fr
       qDebug("addTorrent: Saving save_path in persistent data: %s", qPrintable(savePath));
       TorrentPersistentData::saveSavePath(hash, savePath);
     }
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
     // Append .!qB to incomplete files
     if(appendqBExtension)
       appendqBextensionToTorrent(h, true);
@@ -1283,7 +1317,7 @@ void Bittorrent::enableUPnP(bool b) {
     if(!UPnPEnabled) {
       qDebug("Enabling UPnP");
       s->start_upnp();
-      UPnPEnabled = true;  
+      UPnPEnabled = true;
     }
   } else {
     if(UPnPEnabled) {
@@ -1328,7 +1362,14 @@ void Bittorrent::enableLSD(bool b) {
 
 void Bittorrent::loadSessionState() {
   const QString state_path = misc::cacheLocation()+QDir::separator()+QString::fromUtf8("ses_state");
-#ifdef LIBTORRENT_0_15
+  if(!QFile::exists(state_path)) return;
+  if(QFile(state_path).size() == 0) {
+    // Remove empty state file
+    QFile::remove(state_path);
+    return;
+  }
+
+#if LIBTORRENT_VERSION_MINOR > 14
   std::vector<char> in;
   if (load_file(state_path.toLocal8Bit().constData(), in) == 0)
   {
@@ -1349,19 +1390,17 @@ void Bittorrent::loadSessionState() {
 void Bittorrent::saveSessionState() {
   qDebug("Saving session state to disk...");
   const QString state_path = misc::cacheLocation()+QDir::separator()+QString::fromUtf8("ses_state");
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
   entry session_state;
   s->save_state(session_state);
   std::vector<char> out;
   bencode(std::back_inserter(out), session_state);
   file f;
   error_code ec;
-  if (f.open(state_path.toLocal8Bit().data(), file::write_only, ec)) {
-    if (ec) {
-      file::iovec_t b = {&out[0], out.size()};
-      f.writev(0, &b, 1, ec);
-    }
-  }
+  if (!f.open(state_path.toLocal8Bit().constData(), file::write_only, ec)) return;
+  if (ec) return;
+  file::iovec_t b = {&out[0], out.size()};
+  f.writev(0, &b, 1, ec);
 #else
   entry session_state = s->state();
   boost::filesystem::ofstream out(state_path.toLocal8Bit().constData()
@@ -1375,7 +1414,7 @@ void Bittorrent::saveSessionState() {
 bool Bittorrent::enableDHT(bool b) {
   if(b) {
     if(!DHTEnabled) {
-#ifndef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR < 15
       entry dht_state;
       const QString dht_state_path = misc::cacheLocation()+QDir::separator()+QString::fromUtf8("dht_state");
       if(QFile::exists(dht_state_path)) {
@@ -1387,7 +1426,7 @@ bool Bittorrent::enableDHT(bool b) {
       }
 #endif
       try {
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
         s->start_dht();
 #else
         s->start_dht(dht_state);
@@ -1521,6 +1560,9 @@ void Bittorrent::addConsoleMessage(QString msg, QString) {
     if(consoleMessages.size() > 100) {
       consoleMessages.removeFirst();
     }
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+    msg = msg.replace("/", "\\");
+#endif
     consoleMessages.append(QString::fromUtf8("<font color='grey'>")+ QDateTime::currentDateTime().toString(QString::fromUtf8("dd/MM/yyyy hh:mm:ss")) + QString::fromUtf8("</font> - <font color='") + color.name() +QString::fromUtf8("'><i>") + msg + QString::fromUtf8("</i></font>"));
 #endif
     emit newConsoleMessage(QDateTime::currentDateTime().toString("dd/MM/yyyy hh:mm:ss") + " - " + msg);
@@ -1556,7 +1598,7 @@ void Bittorrent::addConsoleMessage(QString msg, QString) {
     foreach(const QString &file, pathList) {
       qDebug("File %s added", qPrintable(file));
       try {
-        torrent_info t(file.toLocal8Bit().constData());
+        torrent_info t(file.toUtf8().constData());
         if(t.is_valid())
           addTorrent(file, true);
       } catch(std::exception&) {
@@ -1600,7 +1642,7 @@ void Bittorrent::addConsoleMessage(QString msg, QString) {
     defaultTempPath = temppath;
   }
 
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
   void Bittorrent::appendqBextensionToTorrent(QTorrentHandle h, bool append) {
     if(!h.is_valid() || !h.has_metadata()) return;
     std::vector<size_type> fp;
@@ -1609,7 +1651,7 @@ void Bittorrent::addConsoleMessage(QString msg, QString) {
       if(append) {
         const qulonglong file_size = h.filesize_at(i);
         if(file_size > 0 && (fp[i]/(double)file_size) < 1.) {
-          const QString &name = misc::toQString(h.get_torrent_info().file_at(i).path.string());
+          const QString &name = misc::toQStringU(h.get_torrent_info().file_at(i).path.string());
           if(!name.endsWith(".!qB")) {
             const QString new_name = name+".!qB";
             qDebug("Renaming %s to %s", qPrintable(name), qPrintable(new_name));
@@ -1617,7 +1659,7 @@ void Bittorrent::addConsoleMessage(QString msg, QString) {
           }
         }
       } else {
-        QString name = misc::toQString(h.get_torrent_info().file_at(i).path.string());
+        QString name = misc::toQStringU(h.get_torrent_info().file_at(i).path.string());
         if(name.endsWith(".!qB")) {
           const QString old_name = name;
           name.chop(4);
@@ -1651,12 +1693,10 @@ void Bittorrent::addConsoleMessage(QString msg, QString) {
     } else {
       new_save_path = old_dir.absoluteFilePath(new_label);
     }
-    TorrentPersistentData::saveSavePath(h.hash(), new_save_path);
     if(move_storage) {
       // Move storage
       h.move_storage(new_save_path);
     }
-    emit savePathChanged(h);
   }
 
   void Bittorrent::appendLabelToTorrentSavePath(QTorrentHandle h) {
@@ -1668,12 +1708,10 @@ void Bittorrent::addConsoleMessage(QString msg, QString) {
     const QDir old_dir(old_save_path);
     if(old_dir.dirName() != label) {
       const QString &new_save_path = old_dir.absoluteFilePath(label);
-      TorrentPersistentData::saveSavePath(h.hash(), new_save_path);
       if(old_dir == QDir(h.save_path())) {
         // Move storage
         h.move_storage(new_save_path);
       }
-      emit savePathChanged(h);
     }
   }
 
@@ -1692,7 +1730,7 @@ void Bittorrent::addConsoleMessage(QString msg, QString) {
     }
   }
 
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
   void Bittorrent::setAppendqBExtension(bool append) {
     if(appendqBExtension != append) {
       appendqBExtension = !appendqBExtension;
@@ -1850,12 +1888,13 @@ void Bittorrent::addConsoleMessage(QString msg, QString) {
     }
     // We need this for urllib in search engine plugins
 #ifdef Q_WS_WIN
-    char proxystr[512];
+    QString type_str;
     if(proxySettings.type == proxy_settings::socks5 || proxySettings.type == proxy_settings::socks5_pw)
-      snprintf(proxystr, 512, "sock_proxy=%s", proxy_str.toLocal8Bit().constData());
+      type_str = "sock_proxy";
     else
-      snprintf(proxystr, 512, "http_proxy=%s", proxy_str.toLocal8Bit().constData());
-    putenv(proxystr);
+      type_str = "http_proxy";
+    QString tmp = type_str+"="+proxy_str;
+    putenv(tmp.toLocal8Bit().constData());
 #else
     qDebug("HTTP communications proxy string: %s", qPrintable(proxy_str));
     if(proxySettings.type == proxy_settings::socks5 || proxySettings.type == proxy_settings::socks5_pw)
@@ -1867,12 +1906,12 @@ void Bittorrent::addConsoleMessage(QString msg, QString) {
 
   void Bittorrent::recursiveTorrentDownload(const QTorrentHandle &h) {
     for(int i=0; i<h.get_torrent_info().num_files(); ++i) {
-      const QString &torrent_relpath = misc::toQString(h.get_torrent_info().file_at(i).path.string());
+      const QString &torrent_relpath = misc::toQStringU(h.get_torrent_info().file_at(i).path.string());
       if(torrent_relpath.endsWith(".torrent")) {
         addConsoleMessage(tr("Recursive download of file %1 embedded in torrent %2", "Recursive download of test.torrent embedded in torrent test2").arg(torrent_relpath).arg(h.name()));
         const QString torrent_fullpath = h.save_path()+QDir::separator()+torrent_relpath;
         try {
-          boost::intrusive_ptr<torrent_info> t = new torrent_info(torrent_fullpath.toLocal8Bit().constData());
+          boost::intrusive_ptr<torrent_info> t = new torrent_info(torrent_fullpath.toUtf8().constData());
           const QString &sub_hash = misc::toQString(t->info_hash());
           // Passing the save path along to the sub torrent file
           TorrentTempData::setSavePath(sub_hash, h.save_path());
@@ -1895,17 +1934,20 @@ void Bittorrent::addConsoleMessage(QString msg, QString) {
         if(h.is_valid()) {
           emit finishedTorrent(h);
           const QString &hash = h.hash();
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
           // Remove .!qB extension if necessary
           if(appendqBExtension)
             appendqBextensionToTorrent(h, false);
 #endif
+          qDebug("A torrent has finished downloading");
           // Move to download directory if necessary
           if(!defaultTempPath.isEmpty()) {
+            qDebug("A torrent has finished downloading and will be moved to the final download location");
             // Check if directory is different
             const QDir current_dir(h.save_path());
             const QDir save_dir(getSavePath(hash));
             if(current_dir != save_dir) {
+              qDebug("current dir is different that final destination, actually move the storage...");
               h.move_storage(save_dir.path());
             }
           }
@@ -1915,13 +1957,13 @@ void Bittorrent::addConsoleMessage(QString msg, QString) {
             qDebug("Checking if the torrent contains torrent files to download");
             // Check if there are torrent files inside
             for(int i=0; i<h.get_torrent_info().num_files(); ++i) {
-              const QString &torrent_relpath = misc::toQString(h.get_torrent_info().file_at(i).path.string());
+              const QString &torrent_relpath = misc::toQStringU(h.get_torrent_info().file_at(i).path.string());
               if(torrent_relpath.endsWith(".torrent")) {
                 qDebug("Found possible recursive torrent download.");
                 const QString torrent_fullpath = h.save_path()+QDir::separator()+torrent_relpath;
                 qDebug("Full subtorrent path is %s", qPrintable(torrent_fullpath));
                 try {
-                  boost::intrusive_ptr<torrent_info> t = new torrent_info(torrent_fullpath.toLocal8Bit().constData());
+                  boost::intrusive_ptr<torrent_info> t = new torrent_info(torrent_fullpath.toUtf8().constData());
                   if(t->is_valid()) {
                     qDebug("emitting recursiveTorrentDownloadPossible()");
                     emit recursiveTorrentDownloadPossible(h);
@@ -1962,16 +2004,43 @@ void Bittorrent::addConsoleMessage(QString msg, QString) {
           }
         }
       }
+      else if (file_renamed_alert* p = dynamic_cast<file_renamed_alert*>(a.get())) {
+        QTorrentHandle h(p->handle);
+        if(h.is_valid() && h.num_files() > 1) {
+          // Check if folders were renamed
+          QStringList old_path_parts = misc::toQStringU(h.get_torrent_info().orig_files().at(p->index).path.string()).split("/");
+          old_path_parts.removeLast();
+          QString old_path = old_path_parts.join("/");
+          QStringList new_path_parts = misc::toQStringU(p->name).split("/");
+          new_path_parts.removeLast();
+          if(old_path != new_path_parts.join("/")) {
+            old_path = h.save_path()+"/"+old_path;
+            qDebug("Detected folder renaming, attempt to delete old folder: %s", qPrintable(old_path));
+            QDir().rmpath(old_path);
+          }
+        }
+      }
       else if (storage_moved_alert* p = dynamic_cast<storage_moved_alert*>(a.get())) {
         QTorrentHandle h(p->handle);
-        if(h.is_valid())
-          h.force_recheck(); //XXX: Required by libtorrent for now
+        if(h.is_valid()) {
+          // Attempt to remove old folder if empty
+          const QString& old_save_path = TorrentPersistentData::getSavePath(h.hash());
+          const QString new_save_path = QString::fromLocal8Bit(p->path.c_str());
+          qDebug("Torrent moved from %s to %s", qPrintable(old_save_path), qPrintable(new_save_path));
+          qDebug("Attempting to remove %s", qPrintable(old_save_path));
+          if(old_save_path != defaultSavePath && old_save_path != defaultTempPath)
+            QDir().rmdir(old_save_path);
+          if(new_save_path != defaultTempPath)
+            TorrentPersistentData::saveSavePath(h.hash(), new_save_path);
+          emit savePathChanged(h);
+          //h.force_recheck();
+        }
       }
       else if (metadata_received_alert* p = dynamic_cast<metadata_received_alert*>(a.get())) {
         QTorrentHandle h(p->handle);
         if(h.is_valid()) {
           qDebug("Received metadata for %s", qPrintable(h.hash()));
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
           // Append .!qB to incomplete files
           if(appendqBExtension)
             appendqBextensionToTorrent(h, true);
@@ -2022,11 +2091,13 @@ void Bittorrent::addConsoleMessage(QString msg, QString) {
           }
         }
       }
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
       else if (file_completed_alert* p = dynamic_cast<file_completed_alert*>(a.get())) {
         QTorrentHandle h(p->handle);
+        qDebug("A file completed download in torrent %s", qPrintable(h.name()));
         if(appendqBExtension) {
-          QString name = misc::toQString(h.get_torrent_info().file_at(p->index).path.string());
+          qDebug("appendqBTExtension is true");
+          QString name = misc::toQStringU(h.get_torrent_info().file_at(p->index).path.string());
           if(name.endsWith(".!qB")) {
             const QString old_name = name;
             name.chop(4);
@@ -2052,7 +2123,7 @@ void Bittorrent::addConsoleMessage(QString msg, QString) {
             QHash<QString, TrackerInfos> trackers_data = trackersInfos.value(h.hash(), QHash<QString, TrackerInfos>());
             TrackerInfos data = trackers_data.value(tracker_url, TrackerInfos(tracker_url));
             data.last_message = misc::toQString(p->msg);
-#ifndef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR < 15
             data.verified = false;
             ++data.fail_count;
 #endif
@@ -2073,7 +2144,7 @@ void Bittorrent::addConsoleMessage(QString msg, QString) {
           TrackerInfos data = trackers_data.value(tracker_url, TrackerInfos(tracker_url));
           data.last_message = ""; // Reset error/warning message
           data.num_peers = p->num_peers;
-#ifndef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR < 15
           data.fail_count = 0;
           data.verified = true;
 #endif
@@ -2088,7 +2159,7 @@ void Bittorrent::addConsoleMessage(QString msg, QString) {
           const QString &tracker_url = misc::toQString(p->url);
           TrackerInfos data = trackers_data.value(tracker_url, TrackerInfos(tracker_url));
           data.last_message = misc::toQString(p->msg); // Store warning message
-#ifndef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR < 15
           data.verified = true;
           data.fail_count = 0;
 #endif
@@ -2271,6 +2342,19 @@ void Bittorrent::addConsoleMessage(QString msg, QString) {
     const int index = url_skippingDlg.indexOf(QUrl::fromEncoded(url.toLocal8Bit()));
     if(index < 0) {
       // Add file to torrent download list
+#ifdef Q_WS_WIN
+      // Windows hack
+      if(!file_path.endsWith(".torrent")) {
+        Q_ASSERT(QFile::exists(file_path));
+        qDebug("Torrent name does not end with .torrent, fixing...");
+        if(QFile::rename(file_path, file_path+".torrent")) {
+          file_path += ".torrent";
+        } else {
+          qDebug("Failed to rename torrent file!");
+        }
+      }
+      qDebug("Downloading torrent at path: %s", qPrintable(file_path));
+#endif
       emit newDownloadedTorrent(file_path, url);
     } else {
       url_skippingDlg.removeAt(index);
@@ -2294,7 +2378,7 @@ void Bittorrent::addConsoleMessage(QString msg, QString) {
     return sessionStatus.payload_upload_rate;
   }
 
-#ifndef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR < 15
   // Save DHT entry to hard drive
   void Bittorrent::saveDHTEntry() {
     // Save DHT entry
