@@ -58,13 +58,14 @@ class torrentCreatorThread : public QThread {
     }
     void create(QString _input_path, QString _save_path, QStringList _trackers, QStringList _url_seeds, QString _comment, bool _is_private, int _piece_size);
     void sendProgressSignal(int progress);
+    void abortCreation() { abort = true; }
   
   protected:
     void run();
     
   signals:
     void creationFailure(QString msg);
-    void creationSuccess(QString path, const char* branch_path);
+    void creationSuccess(QString path, QString branch_path);
 
   signals:
     void updateProgress(int progress);
@@ -87,6 +88,7 @@ class createtorrent : public QDialog, private Ui::createTorrentDialog{
 
   public slots:
     void updateProgressBar(int progress);
+    void on_cancelButton_clicked();
 
   protected slots:
     void on_createButton_clicked();
@@ -97,7 +99,7 @@ class createtorrent : public QDialog, private Ui::createTorrentDialog{
     void on_addURLSeed_button_clicked();
     void on_removeURLSeed_button_clicked();
     void handleCreationFailure(QString msg);
-    void handleCreationSuccess(QString path, const char* branch_path);
+    void handleCreationSuccess(QString path, QString branch_path);
 };
 
 #endif
