@@ -42,7 +42,9 @@ enum ProxyType {HTTP=1, SOCKS5=2, HTTP_PW=3, SOCKS5_PW=4, SOCKS4=5};
 downloadThread::downloadThread(QObject* parent) : QObject(parent) {
   networkManager = new QNetworkAccessManager(this);
   connect(networkManager, SIGNAL(finished (QNetworkReply*)), this, SLOT(processDlFinished(QNetworkReply*)));
+#ifndef QT_NO_OPENSSL
   connect(networkManager, SIGNAL(sslErrors(QNetworkReply*,QList<QSslError>)), this, SLOT(ignoreSslErrors(QNetworkReply*,QList<QSslError>)));
+#endif
 }
 
 downloadThread::~downloadThread(){
@@ -52,7 +54,7 @@ downloadThread::~downloadThread(){
 }
 
 void downloadThread::processDlFinished(QNetworkReply* reply) {
-  QString url = reply->url().toString();
+  QString url = reply->url().toEncoded().data();
   if(reply->error() != QNetworkReply::NoError) {
     // Failure
     emit downloadFailure(url, errorCodeToString(reply->error()));
@@ -71,24 +73,27 @@ void downloadThread::processDlFinished(QNetworkReply* reply) {
     }
     // Success
     QString filePath;
-    QTemporaryFile tmpfile;
-    tmpfile.setAutoRemove(false);
-    if (tmpfile.open()) {
-      filePath = tmpfile.fileName();
+    QTemporaryFile *tmpfile = new QTemporaryFile;
+    tmpfile->setAutoRemove(false);
+    if (tmpfile->open()) {
+      filePath = tmpfile->fileName();
       qDebug("Temporary filename is: %s", qPrintable(filePath));
       if(reply->open(QIODevice::ReadOnly)) {
         // TODO: Support GZIP compression
-        tmpfile.write(reply->readAll());
+        tmpfile->write(reply->readAll());
         reply->close();
-        tmpfile.close();
+        tmpfile->close();
+        delete tmpfile;
         // Send finished signal
         emit downloadFinished(url, filePath);
       } else {
         // Error when reading the request
-        tmpfile.close();
+        tmpfile->close();
+        delete tmpfile;
         emit downloadFailure(url, tr("I/O Error"));
       }
     } else {
+      delete tmpfile;
       emit downloadFailure(url, tr("I/O Error"));
     }
   }
@@ -215,8 +220,10 @@ QString downloadThread::errorCodeToString(QNetworkReply::NetworkError status) {
   }
 }
 
+#ifndef QT_NO_OPENSSL
 void downloadThread::ignoreSslErrors(QNetworkReply* reply,QList<QSslError> errors) {
   Q_UNUSED(errors)
   // Ignore all SSL errors
   reply->ignoreSslErrors();
 }
+#endif
