@@ -33,24 +33,26 @@
 #include <QFile>
 
 #ifndef DISABLE_GUI
-#include <QApplication>
 #include <QMessageBox>
 #include <QStyleFactory>
 #include <QStyle>
 #include <QSplashScreen>
 #include <QPushButton>
+#ifdef Q_WS_MAC
+#include "qmacapplication.h"
+#else
+#include "qtsingleapplication.h"
+#endif
 #include "GUI.h"
 #include "ico.h"
 #else
-#include <QCoreApplication>
+#include "qtsinglecoreapplication.h"
 #include <iostream>
 #include <stdio.h>
 #include "headlessloader.h"
 #endif
 
 #include <QSettings>
-#include <QLocalSocket>
-#include <sys/types.h>
 
 #if defined(Q_WS_X11) || defined(Q_WS_MAC)
 #include <signal.h>
@@ -58,21 +60,10 @@
 #include "stacktrace.h"
 #endif
 
-#ifdef Q_WS_WIN
-#include <windows.h>
-const int UNLEN = 256;
-#endif
-
 #include <stdlib.h>
 #include "misc.h"
 #include "preferences.h"
 
-#ifdef DISABLE_GUI
-QCoreApplication *app;
-#else
-QApplication *app;
-#endif
-
 class UsageDisplay: public QObject {
   Q_OBJECT
 
@@ -131,13 +122,13 @@ public:
 void sigintHandler(int) {
   signal(SIGINT, 0);
   qDebug("Catching SIGINT, exiting cleanly");
-  app->exit();
+  qApp->exit();
 }
 
 void sigtermHandler(int) {
   signal(SIGTERM, 0);
   qDebug("Catching SIGTERM, exiting cleanly");
-  app->exit();
+  qApp->exit();
 }
 void sigsegvHandler(int) {
   signal(SIGABRT, 0);
@@ -158,66 +149,54 @@ void sigabrtHandler(int) {
 #endif
 
 #ifndef DISABLE_GUI
-void useStyle(QApplication *app, QString style){
+void useStyle(QString style){
   if(!style.isEmpty()) {
     QApplication::setStyle(QStyleFactory::create(style));
   }
-  Preferences::setStyle(app->style()->objectName());
+  Preferences::setStyle(QApplication::style()->objectName());
 }
 #endif
 
 // Main
 int main(int argc, char *argv[]){
+  // Create Application
+  QString uid = misc::getUserIDString();
+  #ifdef DISABLE_GUI
+  QtSingleCoreApplication app("qBittorrent-"+uid, argc, argv);
+  #else
+  #ifndef Q_WS_MAC
+  QtSingleApplication app("qBittorrent-"+uid, argc, argv);
+  #else
+  QMacApplication app("qBittorrent-"+uid, argc, argv);
+  #endif
+  #endif
+
+  // Check if qBittorrent is already running for this user
+  if(app.isRunning()) {
+    qDebug("qBittorrent is already running for this user.");
+    //Pass program parameters if any
+    QString message;
+    for (int a = 1; a < argc; ++a) {
+      QString p = QString::fromLocal8Bit(argv[a]);
+      if(p.startsWith("--")) continue;
+      message += argv[a];
+      if (a < argc-1)
+        message += "|";
+    }
+    if(!message.isEmpty()) {
+      qDebug("Passing program parameters to running instance...");
+      qDebug("Message: %s", qPrintable(message));
+      app.sendMessage(message);
+    }
+    return 0;
+  }
+
   QString locale;
   QSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
 #ifndef DISABLE_GUI
   bool no_splash = false;
 #endif
 
-  //Check if there is another instance running
-  QLocalSocket localSocket;
-  QString uid;
-#ifdef Q_WS_WIN
-  char buffer[UNLEN+1] = {0};
-  DWORD buffer_len = UNLEN + 1;
-  if (!GetUserName(buffer, &buffer_len))
-    uid = QString(buffer)
-#else
-    uid = QString::number(getuid());
-#endif
-  localSocket.connectToServer("qBittorrent-"+uid, QIODevice::WriteOnly);
-  if (localSocket.waitForConnected(1000)){
-    std::cout << "Another qBittorrent instance is already running...\n";
-    // Send parameters
-    if(argc > 1){
-      QStringList params;
-      for(int i=1;i<argc;++i){
-        params << QString::fromLocal8Bit(argv[i]);
-        std::cout << argv[i] << '\n';
-      }
-      QByteArray block = params.join("\n").toLocal8Bit();
-      std::cout << "writting: " << block.data() << '\n';
-      std::cout << "size: " << block.size() << '\n';
-      uint val = localSocket.write(block);
-      if(localSocket.waitForBytesWritten(5000)){
-        std::cout << "written(" <<val<<"): " << block.data() << '\n';
-      }else{
-        std::cerr << "Writing to the socket timed out\n";
-      }
-      localSocket.disconnectFromServer();
-      std::cout << "disconnected\n";
-    }
-    localSocket.close();
-    return 0;
-  }
-
-  // Create Application
-#ifdef DISABLE_GUI
-  app = new QCoreApplication(argc, argv);
-#else
-  app = new QApplication(argc, argv);
-#endif
-
   // Load translation
   locale = settings.value(QString::fromUtf8("Preferences/General/Locale"), QString()).toString();
   QTranslator translator;
@@ -230,19 +209,25 @@ int main(int argc, char *argv[]){
   }else{
     qDebug("%s locale unrecognized, using default (en_GB).", qPrintable(locale));
   }
-  app->installTranslator(&translator);
-  app->setApplicationName(QString::fromUtf8("qBittorrent"));
+  app.installTranslator(&translator);
+#ifndef DISABLE_GUI
+  if(locale.startsWith("ar")) {
+    qDebug("Right to Left mode");
+    app.setLayoutDirection(Qt::RightToLeft);
+  } else {
+    app.setLayoutDirection(Qt::LeftToRight);
+  }
+#endif
+  app.setApplicationName(QString::fromUtf8("qBittorrent"));
 
   // Check for executable parameters
   if(argc > 1){
     if(QString::fromLocal8Bit(argv[1]) == QString::fromUtf8("--version")){
       std::cout << "qBittorrent " << VERSION << '\n';
-      delete app;
       return 0;
     }
     if(QString::fromLocal8Bit(argv[1]) == QString::fromUtf8("--help")){
       UsageDisplay::displayUsage(argv[0]);
-      delete app;
       return 0;
     }
 
@@ -279,8 +264,8 @@ int main(int argc, char *argv[]){
   }
 
 #ifndef DISABLE_GUI
-  useStyle(app, settings.value("Preferences/General/Style", "").toString());
-  app->setStyleSheet("QStatusBar::item { border-width: 0; }");
+  useStyle(settings.value("Preferences/General/Style", "").toString());
+  app.setStyleSheet("QStatusBar::item { border-width: 0; }");
   QSplashScreen *splash = 0;
   if(!no_splash) {
     splash = new QSplashScreen(QPixmap(QString::fromUtf8(":/Icons/skin/splash.png")));
@@ -292,11 +277,10 @@ int main(int argc, char *argv[]){
 #ifndef DISABLE_GUI
     delete splash;
 #endif
-    delete app;
     return 0;
   }
 #ifndef DISABLE_GUI
-  app->setQuitOnLastWindowClosed(false);
+  app.setQuitOnLastWindowClosed(false);
 #endif
 #if defined(Q_WS_X11) || defined(Q_WS_MAC)
   signal(SIGABRT, sigabrtHandler);
@@ -305,36 +289,27 @@ int main(int argc, char *argv[]){
   signal(SIGSEGV, sigsegvHandler);
 #endif
   // Read torrents given on command line
-  QStringList torrentCmdLine = app->arguments();
+  QStringList torrentCmdLine = app.arguments();
   // Remove first argument (program name)
   torrentCmdLine.removeFirst();
 #ifndef DISABLE_GUI
-  GUI *window = new GUI(0, torrentCmdLine);
+  GUI window(0, torrentCmdLine);
   if(!no_splash) {
-    splash->finish(window);
+    splash->finish(&window);
     delete splash;
   }
+  QObject::connect(&app, SIGNAL(messageReceived(const QString&)),
+                   &window, SLOT(processParams(const QString&)));
+  app.setActivationWindow(&window);
 #else
   // Load Headless class
-  HeadlessLoader *loader = new HeadlessLoader(torrentCmdLine);
-#endif
-  int ret =  app->exec();
-
-#if defined(Q_WS_X11) || defined(Q_WS_MAC)
-  // Application has exited, stop catching SIGINT and SIGTERM
-  signal(SIGINT, 0);
-  signal(SIGTERM, 0);
+  HeadlessLoader loader(torrentCmdLine);
+  QObject::connect(&app, SIGNAL(messageReceived(const QString&)),
+                   &loader, SLOT(processParams(const QString&)));
 #endif
 
-#ifndef DISABLE_GUI
-  delete window;
-  qDebug("GUI was deleted!");
-#else
-  delete loader;
-#endif
-  qDebug("Deleting app...");
-  delete app;
-  qDebug("App was deleted! All good.");
+  int ret = app.exec();
+
   return ret;
 }
 
