@@ -39,6 +39,7 @@
 #include <QDesktopWidget>
 #include <QStyleFactory>
 
+#include <libtorrent/version.hpp>
 #include <time.h>
 #include <stdlib.h>
 
@@ -102,12 +103,16 @@ options_imp::options_imp(QWidget *parent):QDialog(parent){
   locales << "cs_CZ";
   comboI18n->addItem((QIcon(QString::fromUtf8(":/Icons/flags/slovakia.png"))), QString::fromUtf8("Slovenčina"));
   locales << "sk_SK";
+  comboI18n->addItem((QIcon(QString::fromUtf8(":/Icons/flags/croatia.png"))), QString::fromUtf8("Hrvatski"));
+  locales << "hr_HR";
   comboI18n->addItem((QIcon(QString::fromUtf8(":/Icons/flags/serbia.png"))), QString::fromUtf8("Српски"));
   locales << "sr_CS";
   comboI18n->addItem((QIcon(QString::fromUtf8(":/Icons/flags/romania.png"))), QString::fromUtf8("Română"));
   locales << "ro_RO";
   comboI18n->addItem((QIcon(QString::fromUtf8(":/Icons/flags/turkey.png"))), QString::fromUtf8("Türkçe"));
   locales << "tr_TR";
+  comboI18n->addItem((QIcon(QString::fromUtf8(":/Icons/flags/saoudi_arabia.png"))), QString::fromUtf8("عربي"));
+  locales << "ar_SA";
   comboI18n->addItem((QIcon(QString::fromUtf8(":/Icons/flags/greece.png"))), QString::fromUtf8("Ελληνικά"));
   locales << "el_GR";
   comboI18n->addItem((QIcon(QString::fromUtf8(":/Icons/flags/sweden.png"))), QString::fromUtf8("Svenska"));
@@ -133,6 +138,7 @@ options_imp::options_imp(QWidget *parent):QDialog(parent){
   comboI18n->addItem((QIcon(QString::fromUtf8(":/Icons/flags/south_korea.png"))), QString::fromUtf8("한글"));
   locales << "ko_KR";
 
+
   // Load week days (scheduler)
   for(uint i=1; i<=7; ++i) {
 #ifdef QT_4_5
@@ -145,7 +151,12 @@ options_imp::options_imp(QWidget *parent):QDialog(parent){
   // Load options
   loadOptions();
   // Disable systray integration if it is not supported by the system
+#ifdef Q_WS_MAC
+  if(1){
+#else
   if(!QSystemTrayIcon::isSystemTrayAvailable()){
+#endif
+    checkNoSystray->setChecked(true);
     checkNoSystray->setEnabled(false);
   }
   // Connect signals / slots
@@ -271,14 +282,18 @@ options_imp::options_imp(QWidget *parent):QDialog(parent){
   connect(textWebUiPassword, SIGNAL(textChanged(QString)), this, SLOT(enableApplyButton()));
   // Disable apply Button
   applyButton->setEnabled(false);
+#ifdef Q_WS_MAC
+  if(1) {
+#else
   if(!QSystemTrayIcon::supportsMessages()){
+#endif
     // Mac OS X doesn't support it yet
     checkSystrayBalloons->setChecked(false);
     checkSystrayBalloons->setEnabled(false);
   }
   // Tab selection mecanism
   connect(tabSelection, SIGNAL(currentItemChanged(QListWidgetItem *, QListWidgetItem *)), this, SLOT(changePage(QListWidgetItem *, QListWidgetItem*)));
-#ifndef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR < 15
   checkAppendqB->setVisible(false);
 #endif
   // Load Advanced settings
@@ -385,11 +400,19 @@ void options_imp::saveOptions(){
   settings.endGroup();
   // Downloads preferences
   settings.beginGroup("Downloads");
-  settings.setValue(QString::fromUtf8("SavePath"), getSavePath());
+  QString save_path = getSavePath();
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+  save_path = save_path.replace("\\", "/");
+#endif
+  settings.setValue(QString::fromUtf8("SavePath"), save_path);
   settings.setValue(QString::fromUtf8("TempPathEnabled"), isTempPathEnabled());
-  settings.setValue(QString::fromUtf8("TempPath"), getTempPath());
+  QString temp_path = getTempPath();
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+  temp_path = temp_path.replace("\\", "/");
+#endif
+  settings.setValue(QString::fromUtf8("TempPath"), temp_path);
   settings.setValue(QString::fromUtf8("AppendLabel"), checkAppendLabel->isChecked());
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
   settings.setValue(QString::fromUtf8("UseIncompleteExtension"), checkAppendqB->isChecked());
 #endif
   settings.setValue(QString::fromUtf8("PreAllocation"), preAllocateAllFiles());
@@ -397,7 +420,11 @@ void options_imp::saveOptions(){
   settings.setValue(QString::fromUtf8("StartInPause"), addTorrentsInPause());
   ScanFoldersModel::instance()->makePersistent(settings);
   addedScanDirs.clear();
-  Preferences::setExportDir(getExportDir());
+  QString export_dir = getExportDir();
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+  export_dir = export_dir.replace("\\", "/");
+#endif
+  Preferences::setExportDir(export_dir);
   settings.setValue(QString::fromUtf8("DblClOnTorDl"), getActionOnDblClOnTorrentDl());
   settings.setValue(QString::fromUtf8("DblClOnTorFn"), getActionOnDblClOnTorrentFn());
   // End Downloads preferences
@@ -483,7 +510,11 @@ void options_imp::saveOptions(){
   settings.beginGroup("IPFilter");
   settings.setValue(QString::fromUtf8("Enabled"), isFilteringEnabled());
   if(isFilteringEnabled()){
-    settings.setValue(QString::fromUtf8("File"), textFilterPath->text());
+    QString filter_path = textFilterPath->text();
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+    filter_path = filter_path.replace("\\", "/");
+#endif
+    settings.setValue(QString::fromUtf8("File"), filter_path);
   }
   // End IPFilter preferences
   settings.endGroup();
@@ -602,7 +633,11 @@ void options_imp::loadOptions(){
   }
   // End General preferences
   // Downloads preferences
-  textSavePath->setText(Preferences::getSavePath());
+  QString save_path = Preferences::getSavePath();
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+  save_path = save_path.replace("/", "\\");
+#endif
+  textSavePath->setText(save_path);
   if(Preferences::isTempPathEnabled()) {
     // enable
     checkTempFolder->setChecked(true);
@@ -611,9 +646,13 @@ void options_imp::loadOptions(){
     checkTempFolder->setChecked(false);
     enableTempPathInput(checkTempFolder->isChecked());
   }
-  textTempPath->setText(Preferences::getTempPath());
+  QString temp_path = Preferences::getTempPath();
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+  temp_path = temp_path.replace("/", "\\");
+#endif
+  textTempPath->setText(temp_path);
   checkAppendLabel->setChecked(Preferences::appendTorrentLabel());
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
   checkAppendqB->setChecked(Preferences::useIncompleteFilesExtension());
 #endif
   checkPreallocateAll->setChecked(Preferences::preAllocateAllFiles());
@@ -628,6 +667,9 @@ void options_imp::loadOptions(){
   } else {
     // enable
     checkExportDir->setChecked(true);
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+    strValue = strValue.replace("/", "\\");
+#endif
     textExportDir->setText(strValue);
     enableTorrentExport(checkExportDir->isChecked());
   }
@@ -990,6 +1032,9 @@ bool options_imp::startMinimized() const {
 }
 
 bool options_imp::systrayIntegration() const{
+#ifdef Q_WS_MAC
+  return false;
+#endif
   if (!QSystemTrayIcon::isSystemTrayAvailable()) return false;
   return (!checkNoSystray->isChecked());
 }
@@ -1016,16 +1061,12 @@ float options_imp::getDeleteRatio() const{
 
 // Return Save Path
 QString options_imp::getSavePath() const{
-#ifdef Q_WS_WIN
-  QString home = QDir::rootPath();
-#else
-  QString home = QDir::homePath();
-#endif
-  if(home[home.length()-1] != QDir::separator()){
-    home += QDir::separator();
-  }
   if(textSavePath->text().trimmed().isEmpty()){
-    textSavePath->setText(home+QString::fromUtf8("qBT_dir"));
+    QString save_path = Preferences::getSavePath();
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+    save_path = save_path.replace("/", "\\");
+#endif
+    textSavePath->setText(save_path);
   }
   return misc::expandPath(textSavePath->text());
 }
@@ -1421,6 +1462,9 @@ void options_imp::on_browseExportDirButton_clicked() {
     dir = QFileDialog::getExistingDirectory(this, tr("Choose export directory"), QDir::homePath());
   }
   if(!dir.isNull()){
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+    dir = dir.replace("/", "\\");
+#endif
     textExportDir->setText(dir);
   }
 }
@@ -1435,6 +1479,9 @@ void options_imp::on_browseFilterButton_clicked() {
     ipfilter = QFileDialog::getOpenFileName(this, tr("Choose an ip filter file"), QDir::homePath(), tr("Filters")+QString(" (*.dat *.p2p *.p2b)"));
   }
   if(!ipfilter.isNull()){
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+    ipfilter = ipfilter.replace("/", "\\");
+#endif
     textFilterPath->setText(ipfilter);
   }
 }
@@ -1450,6 +1497,9 @@ void options_imp::on_browseSaveDirButton_clicked(){
     dir = QFileDialog::getExistingDirectory(this, tr("Choose a save directory"), QDir::homePath());
   }
   if(!dir.isNull()){
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+    dir = dir.replace("/", "\\");
+#endif
     textSavePath->setText(dir);
   }
 }
@@ -1464,6 +1514,9 @@ void options_imp::on_browseTempDirButton_clicked(){
     dir = QFileDialog::getExistingDirectory(this, tr("Choose a save directory"), QDir::homePath());
   }
   if(!dir.isNull()){
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+    dir = dir.replace("/", "\\");
+#endif
     textTempPath->setText(dir);
   }
 }
