@@ -40,6 +40,7 @@
 #include <QFileDialog>
 #include <QDesktopServices>
 #include <QInputDialog>
+#include <libtorrent/version.hpp>
 #include "propertieswidget.h"
 #include "transferlistwidget.h"
 #include "torrentpersistentdata.h"
@@ -101,7 +102,7 @@ PropertiesWidget::PropertiesWidget(QWidget *parent, GUI* main_window, TransferLi
   ProgressHLayout_2->insertWidget(1, pieces_availability);
   // Tracker list
   trackerList = new TrackerList(this);
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
   trackerUpButton->setVisible(false);
   trackerDownButton->setVisible(false);
 #else
@@ -211,6 +212,9 @@ void PropertiesWidget::updateSavePath(QTorrentHandle& _h) {
     QString p = TorrentPersistentData::getSavePath(h.hash());
     if(p.isEmpty())
       p = h.save_path();
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+    p = p.replace("/", "\\");
+#endif
     save_path->setText(p);
   }
 }
@@ -229,6 +233,9 @@ void PropertiesWidget::loadTorrentInfos(QTorrentHandle &_h) {
     QString p = TorrentPersistentData::getSavePath(h.hash());
     if(p.isEmpty())
       p = h.save_path();
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+    p = p.replace("/", "\\");
+#endif
     save_path->setText(p);
     // Creation date
     lbl_creationDate->setText(h.creation_date());
@@ -252,12 +259,12 @@ void PropertiesWidget::loadTorrentInfos(QTorrentHandle &_h) {
 
 void PropertiesWidget::readSettings() {
   QSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
-  QVariantList contentColsWidths = settings.value(QString::fromUtf8("TorrentProperties/filesColsWidth"), QVariantList()).toList();
+  QList<int> contentColsWidths = misc::intListfromStringList(settings.value(QString::fromUtf8("TorrentProperties/filesColsWidth")).toStringList());
   if(contentColsWidths.empty()) {
     filesList->header()->resizeSection(0, 300);
   } else {
     for(int i=0; i<contentColsWidths.size(); ++i) {
-      filesList->setColumnWidth(i, contentColsWidths.at(i).toInt());
+      filesList->setColumnWidth(i, contentColsWidths.at(i));
     }
   }
   // Restore splitter sizes
@@ -279,9 +286,9 @@ void PropertiesWidget::readSettings() {
 void PropertiesWidget::saveSettings() {
   QSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
   settings.setValue("TorrentProperties/Visible", state==VISIBLE);
-  QVariantList contentColsWidths;
+  QStringList contentColsWidths;
   for(int i=0; i<PropListModel->columnCount(); ++i) {
-    contentColsWidths.append(filesList->columnWidth(i));
+    contentColsWidths << QString::number(filesList->columnWidth(i));
   }
   settings.setValue(QString::fromUtf8("TorrentProperties/filesColsWidth"), contentColsWidths);
   // Splitter sizes
@@ -334,7 +341,7 @@ void PropertiesWidget::loadDynamicData() {
       if(ratio > 100.)
         shareRatio->setText(QString::fromUtf8("∞"));
       else
-        shareRatio->setText(QString(QByteArray::number(ratio, 'f', 1)));
+        shareRatio->setText(QString(QByteArray::number(ratio, 'f', 2)));
       if(!h.is_seed()) {
         showPiecesDownloaded(true);
         // Downloaded pieces
@@ -346,8 +353,8 @@ void PropertiesWidget::loadDynamicData() {
           showPiecesAvailability(true);
           std::vector<int> avail;
           h.piece_availability(avail);
-          double avail_average =  pieces_availability->setAvailability(avail);
-          avail_average_lbl->setText(QString::number(avail_average, 'f', 1));
+          pieces_availability->setAvailability(avail);
+          avail_average_lbl->setText(QString::number(h.get_torrent_handle().status().distributed_copies, 'f', 1));
         } else {
           showPiecesAvailability(false);
         }
@@ -474,17 +481,22 @@ void PropertiesWidget::openDoubleClickedFile(QModelIndex index) {
   if(PropListModel->getType(index) == TFILE) {
     int i = PropListModel->getFileIndex(index);
     const QDir &saveDir(h.save_path());
-    const QString &filename = misc::toQString(h.get_torrent_info().file_at(i).path.string());
+    const QString &filename = misc::toQStringU(h.get_torrent_info().file_at(i).path.string());
     const QString &file_path = QDir::cleanPath(saveDir.absoluteFilePath(filename));
     qDebug("Trying to open file at %s", qPrintable(file_path));
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
     // Flush data
     h.flush_cache();
 #endif
-    if(QFile::exists(file_path))
+    if(QFile::exists(file_path)) {
+#ifdef Q_WS_WIN
+      QDesktopServices::openUrl(QUrl("file:///"+file_path));
+#else
       QDesktopServices::openUrl(QUrl("file://"+file_path));
-    else
+#endif
+    } else {
       QMessageBox::warning(this, tr("I/O Error"), tr("This file does not exist yet."));
+    }
   } else {
     // FOLDER
     QStringList path_items;
@@ -498,20 +510,25 @@ void PropertiesWidget::openDoubleClickedFile(QModelIndex index) {
     const QString &filename = path_items.join(QDir::separator());
     const QString &file_path = QDir::cleanPath(saveDir.absoluteFilePath(filename));
     qDebug("Trying to open folder at %s", qPrintable(file_path));
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
     // Flush data
     h.flush_cache();
 #endif
-    if(QFile::exists(file_path))
+    if(QFile::exists(file_path)) {
+#ifdef Q_WS_WIN
+      QDesktopServices::openUrl(QUrl("file:///"+file_path));
+#else
       QDesktopServices::openUrl(QUrl("file://"+file_path));
-    else
+#endif
+    } else {
       QMessageBox::warning(this, tr("I/O Error"), tr("This folder does not exist yet."));
+    }
   }
 }
 
 void PropertiesWidget::displayFilesListMenu(const QPoint&){
   QMenu myFilesLlistMenu;
-  const QModelIndexList &selectedRows = filesList->selectionModel()->selectedRows(0);
+  QModelIndexList selectedRows = filesList->selectionModel()->selectedRows(0);
   QAction *actRename = 0;
   if(selectedRows.size() == 1) {
     actRename = myFilesLlistMenu.addAction(QIcon(QString::fromUtf8(":/Icons/oxygen/edit_clear.png")), tr("Rename..."));
@@ -568,25 +585,27 @@ void PropertiesWidget::renameSelectedFile() {
       // File renaming
       const int file_index = PropListModel->getFileIndex(index);
       if(!h.is_valid() || !h.has_metadata()) return;
-      const QString &old_name = misc::toQString(h.get_torrent_info().file_at(file_index).path.string());
+      QString old_name = misc::toQStringU(h.get_torrent_info().file_at(file_index).path.string());
+      old_name = old_name.replace("\\", "/");
       if(old_name.endsWith(".!qB") && !new_name_last.endsWith(".!qB")) {
         new_name_last += ".!qB";
       }
-      QStringList path_items = old_name.split(QDir::separator());
+      QStringList path_items = old_name.split("/");
       path_items.removeLast();
       path_items << new_name_last;
-      const QString &new_name = path_items.join(QDir::separator());
+      QString new_name = path_items.join("/");
       if(old_name == new_name) {
         qDebug("Name did not change");
         return;
       }
+      new_name = QDir::cleanPath(new_name);
       // Check if that name is already used
       for(int i=0; i<h.num_files(); ++i) {
         if(i == file_index) continue;
 #if defined(Q_WS_X11) || defined(Q_WS_MAC) || defined(Q_WS_QWS)
-        if(misc::toQString(h.get_torrent_info().file_at(i).path.string()).compare(new_name, Qt::CaseSensitive) == 0) {
+        if(misc::toQStringU(h.get_torrent_info().file_at(i).path.string()).compare(new_name, Qt::CaseSensitive) == 0) {
 #else
-          if(misc::toQString(h.get_torrent_info().file_at(i).path.string()).compare(new_name, Qt::CaseInsensitive) == 0) {
+          if(misc::toQStringU(h.get_torrent_info().file_at(i).path.string()).compare(new_name, Qt::CaseInsensitive) == 0) {
 #endif
             // Display error message
             QMessageBox::warning(this, tr("The file could not be renamed"),
@@ -613,15 +632,15 @@ void PropertiesWidget::renameSelectedFile() {
           path_items.prepend(parent.data().toString());
           parent = PropListModel->parent(parent);
         }
-        const QString &old_path = path_items.join(QDir::separator());
+        const QString &old_path = path_items.join("/");
         path_items.removeLast();
         path_items << new_name_last;
-        QString new_path = path_items.join(QDir::separator());
-        if(!new_path.endsWith(QDir::separator())) new_path += QDir::separator();
+        QString new_path = path_items.join("/");
+        if(!new_path.endsWith("/")) new_path += "/";
         // Check for overwriting
         const int num_files = h.num_files();
         for(int i=0; i<num_files; ++i) {
-          const QString current_name = misc::toQString(h.get_torrent_info().file_at(i).path.string());
+          const QString current_name = misc::toQStringU(h.get_torrent_info().file_at(i).path.string());
 #if defined(Q_WS_X11) || defined(Q_WS_MAC) || defined(Q_WS_QWS)
           if(current_name.startsWith(new_path, Qt::CaseSensitive)) {
 #else
@@ -636,12 +655,13 @@ void PropertiesWidget::renameSelectedFile() {
           bool force_recheck = false;
           // Replace path in all files
           for(int i=0; i<num_files; ++i) {
-            const QString &current_name = misc::toQString(h.get_torrent_info().file_at(i).path.string());
+            const QString &current_name = misc::toQStringU(h.get_torrent_info().file_at(i).path.string());
             if(current_name.startsWith(old_path)) {
               QString new_name = current_name;
               new_name.replace(0, old_path.length(), new_path);
-              if(!force_recheck && QFile::exists(h.save_path()+QDir::separator()+new_name))
+              if(!force_recheck && QDir(h.save_path()).exists(new_name))
                 force_recheck = true;
+              new_name = QDir::cleanPath(new_name);
               qDebug("Rename %s to %s", qPrintable(current_name), qPrintable(new_name));
               h.rename_file(i, new_name);
             }
@@ -651,7 +671,7 @@ void PropertiesWidget::renameSelectedFile() {
           // Rename folder in torrent files model too
           PropListModel->setData(index, new_name_last);
           // Remove old folder
-          const QDir old_folder(h.save_path()+QDir::separator()+old_path);
+          const QDir old_folder(h.save_path()+"/"+old_path);
           int timeout = 10;
           while(!misc::removeEmptyTree(old_folder.absolutePath()) && timeout > 0) {
             SleeperThread::msleep(100);
@@ -720,7 +740,7 @@ void PropertiesWidget::renameSelectedFile() {
       }else{
         dir = QFileDialog::getExistingDirectory(this, tr("Choose save path"), QDir::homePath());
       }
-      if(!dir.isNull()){
+      if(!dir.isEmpty()){
         // Check if savePath exists
         QDir savePath(misc::expandPath(dir));
         if(!savePath.exists()){
@@ -729,13 +749,15 @@ void PropertiesWidget::renameSelectedFile() {
             return;
           }
         }
-        // Save savepath
-        TorrentPersistentData::saveSavePath(h.hash(), savePath.absolutePath());
         // Actually move storage
         if(!BTSession->useTemporaryFolder() || h.is_seed())
           h.move_storage(savePath.absolutePath());
         // Update save_path in dialog
-        save_path->setText(savePath.absolutePath());
+        QString display_path = savePath.absolutePath();
+#if defined(Q_WS_WIN) || defined(Q_OS_OS2)
+        display_path = display_path.replace("/", "\\");
+#endif
+        save_path->setText(display_path);
       }
     }
 
