@@ -22,15 +22,26 @@
 # ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 # POSSIBILITY OF SUCH DAMAGE.
 
-#VERSION: 1.02
+#VERSION: 1.31
 
 # Author:
 #  Christophe DUMEZ (chris@qbittorrent.org)
 
 import re, htmlentitydefs
-import urllib2
 import tempfile
 import os
+import StringIO, gzip, urllib2
+import socket
+import socks
+import re
+
+# SOCKS5 Proxy support
+if os.environ.has_key("sock_proxy") and len(os.environ["sock_proxy"].strip()) > 0:
+    proxy_str = os.environ["sock_proxy"].strip()
+    m=re.match(r"^(?:(?P<username>[^:]+):(?P<password>[^@]+)@)?(?P<host>[^:]+):(?P<port>\w+)$", proxy_str)
+    if m is not None:
+        socks.setdefaultproxy(socks.PROXY_TYPE_SOCKS5, m.group('host'), int(m.group('port')), True, m.group('username'), m.group('password'))
+        socket.socket = socks.socksocket
 
 def htmlentitydecode(s):
     # First convert alpha entities (such as &eacute;)
@@ -63,14 +74,24 @@ def retrieve_url(url):
     dat = htmlentitydecode(dat)
     return dat.encode('utf-8', 'replace')
 
-def download_file(url):
+def download_file(url, referer=None):
     """ Download file at url and write it to a file, return the path to the file and the url """
     file, path = tempfile.mkstemp()
-    file = os.fdopen(file, "wb")
+    file = os.fdopen(file, "w")
     # Download url
     req = urllib2.Request(url)
+    if referer is not None:
+        req.add_header('referer', referer)
     response = urllib2.urlopen(req)
     dat = response.read()
+    # Check if it is gzipped
+    if dat[:2] == '\037\213':
+        # Data is gzip encoded, decode it
+        compressedstream = StringIO.StringIO(dat)
+        gzipper = gzip.GzipFile(fileobj=compressedstream)
+        extracted_data = gzipper.read()
+        dat = extracted_data
+        
     # Write it to a file
     file.write(dat)
     file.close()
