@@ -38,6 +38,7 @@
 #include "GUI.h"
 #include "preferences.h"
 #include "deletionconfirmationdlg.h"
+#include <libtorrent/version.hpp>
 #include <QStandardItemModel>
 #include <QSortFilterProxyModel>
 #include <QDesktopServices>
@@ -167,7 +168,7 @@ void TransferListWidget::addTorrent(QTorrentHandle& h) {
     listModel->insertRow(row);
     listModel->setData(listModel->index(row, TR_NAME), QVariant(h.name()));
     listModel->setData(listModel->index(row, TR_SIZE), QVariant((qlonglong)h.actual_size()));
-    listModel->setData(listModel->index(row, TR_ETA), QVariant((qlonglong)-1));
+    listModel->setData(listModel->index(row, TR_ETA), QVariant((qlonglong)MAX_ETA));
     listModel->setData(listModel->index(row, TR_SEEDS), QVariant((double)0.0));
     listModel->setData(listModel->index(row, TR_PEERS), QVariant((double)0.0));
     listModel->setData(listModel->index(row, TR_ADD_DATE), QVariant(TorrentPersistentData::getAddedDate(h.hash())));
@@ -185,6 +186,7 @@ void TransferListWidget::addTorrent(QTorrentHandle& h) {
       if(h.is_seed()) {
         listModel->setData(listModel->index(row, TR_STATUS), STATE_PAUSED_UP);
         listModel->setData(listModel->index(row, TR_NAME), QVariant(QIcon(QString::fromUtf8(":/Icons/skin/pausedUP.png"))), Qt::DecorationRole);
+        listModel->setData(listModel->index(row, TR_ETA), QVariant((qlonglong)0));
       } else {
         listModel->setData(listModel->index(row, TR_STATUS), STATE_PAUSED_DL);
         listModel->setData(listModel->index(row, TR_NAME), QVariant(QIcon(QString::fromUtf8(":/Icons/skin/pausedDL.png"))), Qt::DecorationRole);
@@ -194,6 +196,7 @@ void TransferListWidget::addTorrent(QTorrentHandle& h) {
       if(h.is_seed()) {
         listModel->setData(listModel->index(row, TR_NAME), QVariant(QIcon(QString::fromUtf8(":/Icons/skin/stalledUP.png"))), Qt::DecorationRole);
         listModel->setData(listModel->index(row, TR_STATUS), STATE_STALLED_UP);
+        listModel->setData(listModel->index(row, TR_ETA), QVariant((qlonglong)0));
       } else {
         listModel->setData(listModel->index(row, TR_NAME), QVariant(QIcon(QString::fromUtf8(":/Icons/skin/stalledDL.png"))), Qt::DecorationRole);
         listModel->setData(listModel->index(row, TR_STATUS), STATE_STALLED_DL);
@@ -244,13 +247,13 @@ void TransferListWidget::pauseTorrent(int row, bool refresh_list) {
   const QTorrentHandle &h = BTSession->getTorrentHandle(getHashFromRow(row));
   listModel->setData(listModel->index(row, TR_DLSPEED), QVariant((double)0.0));
   listModel->setData(listModel->index(row, TR_UPSPEED), QVariant((double)0.0));
-  listModel->setData(listModel->index(row, TR_ETA), QVariant((qlonglong)-1));
   if(h.is_seed()) {
     listModel->setData(listModel->index(row, TR_STATUS), STATE_PAUSED_UP);
     listModel->setData(listModel->index(row, TR_NAME), QIcon(QString::fromUtf8(":/Icons/skin/pausedUP.png")), Qt::DecorationRole);
   } else {
     listModel->setData(listModel->index(row, TR_STATUS), STATE_PAUSED_DL);
     listModel->setData(listModel->index(row, TR_NAME), QIcon(QString::fromUtf8(":/Icons/skin/pausedDL.png")), Qt::DecorationRole);
+    listModel->setData(listModel->index(row, TR_ETA), QVariant((qlonglong)MAX_ETA));
   }
   listModel->setData(listModel->index(row, TR_SEEDS), QVariant(0.0));
   listModel->setData(listModel->index(row, TR_PEERS), QVariant(0.0));
@@ -349,7 +352,7 @@ int TransferListWidget::updateTorrent(int row) {
           }
           listModel->setData(listModel->index(row, TR_STATUS), s);
         }else {
-          listModel->setData(listModel->index(row, TR_ETA), QVariant((qlonglong)-1));
+          listModel->setData(listModel->index(row, TR_ETA), QVariant((qlonglong)MAX_ETA));
           if(h.is_seed()) {
             s = STATE_QUEUED_UP;            
             listModel->setData(listModel->index(row, TR_NAME), QVariant(QIcon(QString::fromUtf8(":/Icons/skin/queuedUP.png"))), Qt::DecorationRole);
@@ -394,7 +397,7 @@ int TransferListWidget::updateTorrent(int row) {
       }
       listModel->setData(listModel->index(row, TR_PROGRESS), QVariant((double)h.progress()));
       if(!isColumnHidden(TR_ETA))
-        listModel->setData(listModel->index(row, TR_ETA), QVariant((qlonglong)-1));
+        listModel->setData(listModel->index(row, TR_ETA), QVariant((qlonglong)MAX_ETA));
       setRowColor(row, QString::fromUtf8("grey"));
       break;
     case torrent_status::downloading:
@@ -408,7 +411,7 @@ int TransferListWidget::updateTorrent(int row) {
       }else{
         listModel->setData(listModel->index(row, TR_NAME), QVariant(QIcon(QString::fromUtf8(":/Icons/skin/stalledDL.png"))), Qt::DecorationRole);
         if(!isColumnHidden(TR_ETA))
-          listModel->setData(listModel->index(row, TR_ETA), QVariant((qlonglong)-1));
+          listModel->setData(listModel->index(row, TR_ETA), QVariant((qlonglong)MAX_ETA));
         s = STATE_STALLED_DL;
         setRowColor(row, QApplication::palette().color(QPalette::WindowText));
       }
@@ -454,7 +457,7 @@ void TransferListWidget::setFinished(QTorrentHandle &h) {
         listModel->setData(listModel->index(row, TR_STATUS), STATE_STALLED_UP);
         setRowColor(row, QApplication::palette().color(QPalette::WindowText));
       }
-      listModel->setData(listModel->index(row, TR_ETA), QVariant((qlonglong)-1));
+      listModel->setData(listModel->index(row, TR_ETA), QVariant((qlonglong)0));
       listModel->setData(listModel->index(row, TR_DLSPEED), QVariant((double)0.));
       listModel->setData(listModel->index(row, TR_PROGRESS), QVariant((double)1.));
       listModel->setData(listModel->index(row, TR_PRIORITY), QVariant((int)-1));
@@ -720,9 +723,14 @@ void TransferListWidget::openSelectedTorrentsFolder() const {
     const QTorrentHandle &h = BTSession->getTorrentHandle(hash);
     if(h.is_valid()) {
       const QString &savePath = h.root_path();
+      qDebug("Opening path at %s", qPrintable(savePath));
       if(!pathsList.contains(savePath)) {
         pathsList.append(savePath);
+#ifdef Q_WS_WIN
+        QDesktopServices::openUrl(QUrl(QString("file:///")+savePath));
+#else
         QDesktopServices::openUrl(QUrl(QString("file://")+savePath));
+#endif
       }
     }
   }
@@ -864,23 +872,24 @@ void TransferListWidget::displayDLHoSMenu(const QPoint&){
       actions.append(0);
       continue;
     }
-    QIcon icon;
-    if(isColumnHidden(i))
-      icon = QIcon(QString::fromUtf8(":/Icons/oxygen/button_cancel.png"));
-    else
-      icon = QIcon(QString::fromUtf8(":/Icons/oxygen/button_ok.png"));
-    actions.append(hideshowColumn.addAction(icon, listModel->headerData(i, Qt::Horizontal).toString()));
+    QAction *myAct = hideshowColumn.addAction(listModel->headerData(i, Qt::Horizontal).toString());
+    myAct->setCheckable(true);
+    myAct->setChecked(!isColumnHidden(i));
+    actions.append(myAct);
   }
   // Call menu
-  QAction *act = 0;
-  act = hideshowColumn.exec(QCursor::pos());
+  QAction *act = hideshowColumn.exec(QCursor::pos());
   if(act) {
     int col = actions.indexOf(act);
+    Q_ASSERT(col >= 0);
+    qDebug("Toggling column %d visibility", col);
     setColumnHidden(col, !isColumnHidden(col));
+    if(!isColumnHidden(col) && columnWidth(col) <= 5)
+      setColumnWidth(col, 100);
   }
 }
 
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
 void TransferListWidget::toggleSelectedTorrentsSuperSeeding() const {
   const QStringList &hashes = getSelectedTorrentsHashes();
   foreach(const QString &hash, hashes) {
@@ -1001,22 +1010,25 @@ void TransferListWidget::displayListMenu(const QPoint&) {
   connect(&actionForce_recheck, SIGNAL(triggered()), this, SLOT(recheckSelectedTorrents()));
   QAction actionCopy_magnet_link(QIcon(QString::fromUtf8(":/Icons/magnet.png")), tr("Copy magnet link"), 0);
   connect(&actionCopy_magnet_link, SIGNAL(triggered()), this, SLOT(copySelectedMagnetURIs()));
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
   QAction actionSuper_seeding_mode(tr("Super seeding mode"), 0);
+  actionSuper_seeding_mode.setCheckable(true);
   connect(&actionSuper_seeding_mode, SIGNAL(triggered()), this, SLOT(toggleSelectedTorrentsSuperSeeding()));
 #endif
   QAction actionRename(QIcon(QString::fromUtf8(":/Icons/oxygen/edit_clear.png")), tr("Rename..."), 0);
   connect(&actionRename, SIGNAL(triggered()), this, SLOT(renameSelectedTorrent()));
   QAction actionSequential_download(tr("Download in sequential order"), 0);
+  actionSequential_download.setCheckable(true);
   connect(&actionSequential_download, SIGNAL(triggered()), this, SLOT(toggleSelectedTorrentsSequentialDownload()));
   QAction actionFirstLastPiece_prio(tr("Download first and last piece first"), 0);
+  actionFirstLastPiece_prio.setCheckable(true);
   connect(&actionFirstLastPiece_prio, SIGNAL(triggered()), this, SLOT(toggleSelectedFirstLastPiecePrio()));
   // End of actions
   QMenu listMenu(this);
   // Enable/disable pause/start action given the DL state
   QModelIndexList selectedIndexes = selectionModel()->selectedRows();
   bool has_pause = false, has_start = false, has_preview = false;
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
   bool all_same_super_seeding = true;
   bool super_seeding_mode = false;
 #endif
@@ -1050,7 +1062,7 @@ void TransferListWidget::displayListMenu(const QPoint&) {
         }
       }
     }
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
     else {
       if(!one_not_seed && all_same_super_seeding && h.has_metadata()) {
         if(first) {
@@ -1086,7 +1098,8 @@ void TransferListWidget::displayListMenu(const QPoint&) {
   if(selectedIndexes.size() == 1)
     listMenu.addAction(&actionRename);
   // Label Menu
-  const QStringList &customLabels = getCustomLabels();
+  QStringList customLabels = getCustomLabels();
+  customLabels.sort();
   QList<QAction*> labelActions;
   QMenu *labelMenu = listMenu.addMenu(QIcon(":/Icons/oxygen/feed-subscribe.png"), tr("Label"));
   labelActions << labelMenu->addAction(QIcon(":/Icons/oxygen/list-add.png"), tr("New...", "New label..."));
@@ -1099,15 +1112,9 @@ void TransferListWidget::displayListMenu(const QPoint&) {
   if(one_not_seed)
     listMenu.addAction(&actionSet_download_limit);
   listMenu.addAction(&actionSet_upload_limit);
-#ifdef LIBTORRENT_0_15
+#if LIBTORRENT_VERSION_MINOR > 14
   if(!one_not_seed && all_same_super_seeding && one_has_metadata) {
-    QIcon ico;
-    if(super_seeding_mode) {
-      ico = QIcon(":/Icons/oxygen/button_ok.png");
-    } else {
-      ico = QIcon(":/Icons/oxygen/button_cancel.png");
-    }
-    actionSuper_seeding_mode.setIcon(ico);
+    actionSuper_seeding_mode.setChecked(super_seeding_mode);
     listMenu.addAction(&actionSuper_seeding_mode);
   }
 #endif
@@ -1119,24 +1126,12 @@ void TransferListWidget::displayListMenu(const QPoint&) {
   }
   if(one_not_seed && one_has_metadata) {
     if(all_same_sequential_download_mode) {
-      QIcon ico;
-      if(sequential_download_mode) {
-        ico = QIcon(":/Icons/oxygen/button_ok.png");
-      } else {
-        ico = QIcon(":/Icons/oxygen/button_cancel.png");
-      }
-      actionSequential_download.setIcon(ico);
+      actionSequential_download.setChecked(sequential_download_mode);
       listMenu.addAction(&actionSequential_download);
       added_preview_action = true;
     }
     if(all_same_prio_firstlast) {
-      QIcon ico;
-      if(prioritize_first_last) {
-        ico = QIcon(":/Icons/oxygen/button_ok.png");
-      } else {
-        ico = QIcon(":/Icons/oxygen/button_cancel.png");
-      }
-      actionFirstLastPiece_prio.setIcon(ico);
+      actionFirstLastPiece_prio.setChecked(prioritize_first_last);
       listMenu.addAction(&actionFirstLastPiece_prio);
       added_preview_action = true;
     }
@@ -1186,6 +1181,7 @@ void TransferListWidget::saveColWidthList() {
   QStringList width_list;
   QStringList new_width_list;
   const short nbColumns = listModel->columnCount()-1; // HASH is hidden
+  if(nbColumns <= 0) return;
   const QString &line = settings.value("TransferListColsWidth", QString()).toString();
   if(!line.isEmpty()) {
     width_list = line.split(' ');
@@ -1204,9 +1200,9 @@ void TransferListWidget::saveColWidthList() {
     }
   }
   settings.setValue(QString::fromUtf8("TransferListColsWidth"), new_width_list.join(QString::fromUtf8(" ")));
-  QVariantList visualIndexes;
+  QStringList visualIndexes;
   for(int i=0; i<nbColumns; ++i) {
-    visualIndexes.append(header()->visualIndex(i));
+    visualIndexes << QString::number(header()->visualIndex(i));
   }
   settings.setValue(QString::fromUtf8("TransferListVisualIndexes"), visualIndexes);
   qDebug("Download list columns width saved");
@@ -1216,10 +1212,10 @@ void TransferListWidget::saveColWidthList() {
 bool TransferListWidget::loadColWidthList() {
   qDebug("Loading columns width for download list");
   QSettings settings(QString::fromUtf8("qBittorrent"), QString::fromUtf8("qBittorrent"));
-  const QString &line = settings.value(QString::fromUtf8("TransferListColsWidth"), QString()).toString();
+  QString line = settings.value(QString::fromUtf8("TransferListColsWidth"), QString()).toString();
   if(line.isEmpty())
     return false;
-  const QStringList &width_list = line.split(QString::fromUtf8(" "));
+  const QStringList width_list = line.split(" ");
   if(width_list.size() != listModel->columnCount()-1) {
     qDebug("Corrupted values for transfer list columns sizes");
     return false;
@@ -1228,7 +1224,7 @@ bool TransferListWidget::loadColWidthList() {
   for(unsigned int i=0; i<listSize; ++i) {
     header()->resizeSection(i, width_list.at(i).toInt());
   }
-  const QVariantList& visualIndexes = settings.value(QString::fromUtf8("TransferListVisualIndexes"), QVariantList()).toList();
+  const QList<int> visualIndexes = misc::intListfromStringList(settings.value(QString::fromUtf8("TransferListVisualIndexes")).toStringList());
   if(visualIndexes.size() != listModel->columnCount()-1) {
     qDebug("Corrupted values for transfer list columns indexes");
     return false;
@@ -1237,7 +1233,7 @@ bool TransferListWidget::loadColWidthList() {
   do {
     change = false;
     for(int i=0;i<visualIndexes.size(); ++i) {
-      const int new_visual_index = visualIndexes.at(header()->logicalIndex(i)).toInt();
+      const int new_visual_index = visualIndexes.at(header()->logicalIndex(i));
       if(i != new_visual_index) {
         qDebug("Moving column from %d to %d", header()->logicalIndex(i), new_visual_index);
         header()->moveSection(i, new_visual_index);
