@@ -142,7 +142,7 @@ window.addEvent('load', function(){
   
   var saveColumnSizes = function() {
     var filters_width = $('Filters').getSize().x;
-    var properties_height = $('properties').getSize().y;
+    var properties_height = $('propertiesPanel').getSize().y;
     // Save it in a cookie
     Cookie.write('filters_width', filters_width);
     Cookie.write('properties_height', properties_height);
@@ -184,35 +184,6 @@ window.addEvent('load', function(){
 		column: 'filtersColumn',
 		height: 300
 	});
-    new MochaUI.Panel({
-		id: 'transferList',
-		title: 'Panel',
-		header: false,
-		padding: { top: 0, right: 0, bottom: 0, left: 0 },
-		loadMethod: 'xhr',
-		contentURL: 'transferlist.html',
-		column: 'mainColumn',
-		onResize: saveColumnSizes,
-		height: null
-	});
-    var prop_h = Cookie.read('properties_height');
-    if($defined(prop_h))
-      prop_h = prop_h.toInt();
-    else
-      prop_h = 200;
-    new MochaUI.Panel({
-		id: 'properties',
-		title: 'Panel',
-		header: true,
-		padding: { top: 0, right: 0, bottom: 0, left: 0 },
-		contentURL: 'prop-general.html',
-		require: {
-                  css: ['css/Tabs.css']
-                },
-                tabsURL: 'properties.html',
-		column: 'mainColumn',
-		height: prop_h
-	});
   initializeWindows();
   var r=0;
   var waiting=false;
@@ -315,7 +286,39 @@ window.addEvent('load', function(){
 			}).send();
 		}
 	};
-	ajaxfn();
+  new MochaUI.Panel({
+		id: 'transferList',
+		title: 'Panel',
+		header: false,
+		padding: { top: 0, right: 0, bottom: 0, left: 0 },
+		loadMethod: 'xhr',
+		contentURL: 'transferlist.html',
+    onContentLoaded: function() {
+      ajaxfn();
+    },
+		column: 'mainColumn',
+		onResize: saveColumnSizes,
+		height: null
+	});
+    var prop_h = Cookie.read('properties_height');
+    if($defined(prop_h))
+      prop_h = prop_h.toInt();
+    else
+      prop_h = 200;
+    new MochaUI.Panel({
+		id: 'propertiesPanel',
+		title: 'Panel',
+		header: true,
+		padding: { top: 0, right: 0, bottom: 0, left: 0 },
+		contentURL: 'prop-general.html',
+		require: {
+                  css: ['css/Tabs.css']
+                },
+                tabsURL: 'properties.html',
+		column: 'mainColumn',
+		height: prop_h
+	});
+	//ajaxfn();
   if(BrowserDetect.browser != "Safari") {
     // Safari has trouble with this
     loadTransferInfo();
